@@ -32,7 +32,8 @@ use strict;
 use warnings;
 use FindBin;
 use Getopt::Long;
-use IO;
+use IO::Handle;
+use IO::File;
 
 #   program information
 my $prg = {
